# higlass-schema

Pydantic models for HiGlass

```
pip install higlass-schema
```

🚧 👷


## Development

```
$ pip install -e .
$ hgschema export # prints json schema
$ hgschema check ./example.json # validates json
```


## Release

```
git tag -a v0.0.0 -m "v0.0.0"
git push --follow-tags
```
